@@ -12,10 +12,6 @@ if [[ $INSTALL_RECOMMENDED != false ]]; then
 	[[ $(command -v polkitd) == "" ]] && echo "Installing polkit" && extension --install polkit && echo "Finished polkit"
 	[[ $(command -v valac) == "" ]] && echo "Installing vala" && extension --install vala && echo "Finished vala"
 fi
-# Optional
-if [[ $INSTALL_OPTIONAL != false ]]; then 
-	[[ $(command -v gtkdocize) == "" ]] && echo "Installing gtk_doc" && extension --install gtk_doc && echo "Finished gtk_doc"
-fi
 
 if [ $BUILD_ALL == "false" ] && [[ $(command -v ModemManager) == "" ]]; then
 	echo "modemmanager" 								>> $EXTENSION/build_order.txt
